# Rustic AI Ray

This module supports execution of [Rustic AI](https://www.rustic.ai/) on [Ray Cluster](https://docs.ray.io/en/latest/cluster/getting-started.html).

## Installing

```shell
pip install rusticai-ray
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```
